'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var core = require('use-intl/core');
var RequestLocale = require('./RequestLocale.js');
var getRuntimeConfig = require('next-intl/config');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var getRuntimeConfig__default = /*#__PURE__*/_interopDefault(getRuntimeConfig);

// Make sure `now` is consistent across the request in case none was configured
function getDefaultNowImpl() {
  return new Date();
}
const getDefaultNow = React.cache(getDefaultNowImpl);

// This is automatically inherited by `NextIntlClientProvider` if
// the component is rendered from a Server Component
function getDefaultTimeZoneImpl() {
  return Intl.DateTimeFormat().resolvedOptions().timeZone;
}
const getDefaultTimeZone = React.cache(getDefaultTimeZoneImpl);
async function receiveRuntimeConfigImpl(localeOverride, getConfig) {
  var _result, _result2, _result3;
  // In case the consumer doesn't read `params.locale` and instead provides the
  // `locale` (either in a single-language workflow or because the locale is
  // read from the user settings), don't attempt to read the request locale.
  const params = {
    get locale() {
      return localeOverride || RequestLocale.getRequestLocale();
    }
  };
  let result = getConfig === null || getConfig === void 0 ? void 0 : getConfig(params);
  if (result instanceof Promise) {
    result = await result;
  }
  return {
    ...result,
    locale: ((_result = result) === null || _result === void 0 ? void 0 : _result.locale) || params.locale,
    now: ((_result2 = result) === null || _result2 === void 0 ? void 0 : _result2.now) || getDefaultNow(),
    timeZone: ((_result3 = result) === null || _result3 === void 0 ? void 0 : _result3.timeZone) || getDefaultTimeZone()
  };
}
const receiveRuntimeConfig = React.cache(receiveRuntimeConfigImpl);
async function getConfigImpl(localeOverride) {
  const runtimeConfig = await receiveRuntimeConfig(localeOverride, getRuntimeConfig__default.default);
  return core.initializeConfig(runtimeConfig);
}
const getConfig = React.cache(getConfigImpl);
var getConfig$1 = getConfig;

exports.default = getConfig$1;
